@@ -1,7 +1,7 @@
 #!/usr/local/bin/python2.5
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2003-2007 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2003-2008 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,24 +20,25 @@
 # Authors: Don Welch, Smith Kennedy
 #
 
-__version__ = '4.3'
+__version__ = '5.0'
 __title__ = 'Device URI Creation Utility'
+__mod__ = 'hp-makeuri'
 __doc__ = "Creates device URIs for local and network connected printers for use with CUPS."
 
 # Std Lib
 import sys
 import re
 import getopt
-import socket
+import os
 
 # Local
 from base.g import *
 from base.codes import *
-from base import device, utils
+from base import device, utils, module
 
 
 USAGE = [ (__doc__, "", "name", True),
-          ("Usage: hp-makeuri [OPTIONS] [SERIAL NO.|USB ID|IP|DEVNODE]", "", "summary", True),
+          ("Usage: %s [OPTIONS] [SERIAL NO.|USB ID|IP|DEVNODE]" % __mod__, "", "summary", True),
           ("[SERIAL NO.|USB ID|IP|DEVNODE]", "", "heading", False),
           ("USB IDs (usb only):", """"xxx:yyy" where xxx is the USB bus ID and yyy is the USB device ID. The ':' and all leading zeroes must be present.""", 'option', False),
           ("", """(Use the 'lsusb' command to obtain this information. See Note 1.)""", "option", False),
@@ -68,124 +69,93 @@ USAGE = [ (__doc__, "", "name", True),
           ("hp-setup", "", "seealso", False),
         ]
 
-def usage(typ='text'):
-    if typ == 'text':
-        utils.log_title(__title__, __version__)
 
-    utils.format_text(USAGE, typ, __title__, 'hp-makeuri', __version__)
-    sys.exit(0)
+mod = module.Module(__mod__, __title__, __version__, __doc__, USAGE, 
+                    (INTERACTIVE_MODE,), None, True, True)
 
-
-
-log.set_module('hp-makeuri')
+opts, device_uri, printer_name, mode, ui_toolkit, lang = \
+    mod.parseStdOpts('p:csf', ['port', 'cups', 'sane', 'fax'],
+                     handle_device_printer=False)
 
 try:
-    opts, args = getopt.getopt(sys.argv[1:], 
-                                'hl:csfp:g', 
-                                ['help', 'help-rest', 'help-man', 'help-desc',
-                                  'logging=',
-                                  'cups',
-                                  'sane',
-                                  'fax',
-                                  'port=',
-                                ] 
-                              ) 
-except getopt.GetoptError, e:
-    log.error(e.msg)
-    usage()
-    sys.exit(1)
+    cups_quiet_mode = False
+    sane_quiet_mode = False
+    fax_quiet_mode = False
+    jd_port = 1
 
-if os.getenv("HPLIP_DEBUG"):
-    log.set_level('debug')
+    for o, a in opts:
+        if o in ('-c', '--cups'):
+            cups_quiet_mode = True
 
-log_level = 'info'
-cups_quiet_mode = False
-sane_quiet_mode = False
-fax_quiet_mode = False
-jd_port = 1
+        elif o in ('-s', '--sane'):
+            sane_quiet_mode = True
 
-for o, a in opts:
+        elif o in ('-f', '--fax'):
+            fax_quiet_mode = True
 
-    if o in ('-h', '--help'):
-        usage()
+        elif o in ('-p', '--port'):
+            try:
+                jd_port = int(a)
+            except ValueError:
+                mod.usage(error_msg=["Invalid port number. Must be between 1 and 3 inclusive."])
 
-    elif o == '--help-rest':
-        usage('rest')
-
-    elif o == '--help-man':
-        usage('man')
-
-    elif o == '--help-desc':
-        print __doc__,
-        sys.exit(0)
-
-    elif o in ('-l', '--logging'):
-        log_level = a.lower().strip()
-        if not log.set_level(log_level):
-            usage()
-
-    elif o in ('-c', '--cups'):
-        cups_quiet_mode = True
-
-    elif o in ('-s', '--sane'):
-        sane_quiet_mode = True
-
-    elif o in ('-f', '--fax'):
-        fax_quiet_mode = True
-
-    elif o in ('-p', '--port'):
-        try:
-            jd_port = int(a)
-        except ValueError:
-            log.error("Invalid port number. Must be between 1 and 3 inclusive.")
-            usage()
-
-    elif o == '-g':
-        log.set_level('debug')
+        elif o == '-g':
+            log.set_level('debug')
 
 
-quiet_mode = cups_quiet_mode or sane_quiet_mode or fax_quiet_mode
+    quiet_mode = cups_quiet_mode or sane_quiet_mode or fax_quiet_mode
+    mod.quiet = quiet_mode
+    
+    #if quiet_mode:
+    #    log.set_level('warn')
 
-if quiet_mode:
-    log.set_level('warn')
+    #utils.log_title(__title__, __version__) 
+    mod.showTitle()
 
-utils.log_title(__title__, __version__)    
+    if len(mod.args) != 1:
+        mod.usage(error_msg=["You must specify one SERIAL NO., IP, USB ID or DEVNODE parameter."])
 
-if len(args) != 1:
-    log.error("You must specify one SERIAL NO., IP, USB ID or DEVNODE on the command line.")
-    usage()
+    param = mod.args[0]
 
-param = args[0]
+    if 'localhost' in param.lower():
+        mod.usage(error_msg=['Invalid hostname'])
 
-if 'localhost' in param.lower():
-    log.error("Invalid hostname")
-    usage()
+    cups_uri, sane_uri, fax_uri = device.makeURI(param, jd_port)
 
-cups_uri, sane_uri, fax_uri = device.makeURI(param, jd_port)
+    if not cups_uri:
+        log.error("Device not found")
+        sys.exit(1)
 
-if not cups_uri:
-    log.error("Device not found")
-    sys.exit(1)
+    if cups_quiet_mode:
+        print cups_uri
 
-if cups_quiet_mode:
-    print cups_uri
-elif not quiet_mode:    
-    print "CUPS URI:", cups_uri
+    elif not quiet_mode:    
+        print "CUPS URI: %s" % cups_uri
 
-if sane_uri:
-    if sane_quiet_mode:
-        print sane_uri
-    elif not quiet_mode:
-        print "SANE URI:", sane_uri
-elif not sane_uri and sane_quiet_mode:
-    log.error("Device does not support scan.")
+    if sane_uri:
+        if sane_quiet_mode:
+            print sane_uri
+        
+        elif not quiet_mode:
+            print "SANE URI: %s" % sane_uri
+    
+    elif not sane_uri and sane_quiet_mode:
+        log.error("Device does not support scan.")
 
-if fax_uri:
-    if fax_quiet_mode:
-        print fax_uri
-    elif not quiet_mode:
-        print "HP Fax URI:", fax_uri
-elif not fax_uri and fax_quiet_mode:
-    log.error("Device does not support fax.")
+    if fax_uri:
+        if fax_quiet_mode:
+            print fax_uri
+        
+        elif not quiet_mode:
+            print "HP Fax URI: %s" % fax_uri
+            
+    elif not fax_uri and fax_quiet_mode:
+        log.error("Device does not support fax.")
+
+except KeyboardInterrupt:
+    log.error("User exit")
+
+if not quiet_mode:
+    log.info("")
+    log.info("Done.")
 
-sys.exit(0)
