@@ -1,7 +1,7 @@
 #!/usr/local/bin/python2.5
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2003-2007 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2003-2009 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,62 +20,34 @@
 # Author: Don Welch
 #
 
-__version__ = '3.2'
+__version__ = '3.3'
+__mod__ = 'hp-unload'
 __title__ = 'Photo Card Access Utility'
 __doc__ = "Access inserted photo cards on supported HPLIP printers. This provides an alternative for older devices that do not support USB mass storage or for access to photo cards over a network."
 
 # Std Lib
 import sys
-import os, os.path
+import os
+import os.path
 import getopt
 import re
 import cmd
-import readline
 import time
 import fnmatch
 import string
 import operator
 
+try:
+    import readline
+except ImportError:
+    pass
+
 # Local
 from base.g import *
-from base import device, service, utils #, exif
+from base import device, utils, tui, module
 from prnt import cups
 from pcard import photocard
 
-log.set_module('hp-unload')
-
-
-USAGE = [(__doc__, "", "name", True),
-         ("Usage: hp-unload [PRINTER|DEVICE-URI] [MODE] [OPTIONS]", "", "summary", True),
-         utils.USAGE_ARGS,
-         utils.USAGE_DEVICE,
-         utils.USAGE_PRINTER,
-         utils.USAGE_SPACE,
-         ("[MODE]", "", "header", False),
-         ("Enter interactive mode (ftp-like interface):", "-i or --interactive", "option", False),
-         ("Enter graphical UI mode:", "-u or --gui (Default)", "option", False),
-         ("Run in non-interactive mode (batch mode):", "-n or --non-interactive", "option", False),
-         # TODO: File glob(s)
-         utils.USAGE_SPACE,
-         utils.USAGE_OPTIONS,
-         ("Output directory:", "-o<dir> or --output=<dir> (Defaults to current directory)(Only used for non-GUI modes)", "option", False),
-         utils.USAGE_BUS1, utils.USAGE_BUS2,
-         utils.USAGE_LANGUAGE,
-         utils.USAGE_LOGGING1, utils.USAGE_LOGGING2, utils.USAGE_LOGGING3,
-         utils.USAGE_HELP,
-         utils.USAGE_SPACE,
-         utils.USAGE_NOTES,
-         utils.USAGE_STD_NOTES1, utils.USAGE_STD_NOTES2, 
-         ("3. Use 'help' command at the pcard:> prompt for command help (Interactive mode (-i) only).", "", "note", True),
-         ]
-
-def usage(typ='text'):
-    if typ == 'text':
-        utils.log_title(__title__, __version__)
-
-    utils.format_text(USAGE, typ, __title__, 'hp-unload', __version__)
-    sys.exit(0)
-
 
 # Console class (from ASPN Python Cookbook)
 # Author:   James Thiele
@@ -606,191 +578,84 @@ def status_callback(src, trg, size):
 
 
 
-try:
-    opts, args = getopt.getopt(sys.argv[1:], 'p:d:hb:l:giuno:q:',
-                               ['printer=', 'device=', 'help', 'help-rest', 'help-man',
-                                'bus=', 'logging=', 'interactive', 'gui', 'non-interactive',
-                                'output=', 'help-desc', 'lang='])
-except getopt.GetoptError, e:
-    log.error(e.msg)
-    usage()
+mod = module.Module(__mod__, __title__, __version__, __doc__, None,
+                    (GUI_MODE, INTERACTIVE_MODE, NON_INTERACTIVE_MODE),
+                    (UI_TOOLKIT_QT3,))
+
+mod.setUsage(module.USAGE_FLAG_DEVICE_ARGS,
+    extra_options=[("Output directory:", "-o<dir> or --output=<dir> (Defaults to current directory)(Only used for non-GUI modes)", "option", False)],
+    see_also_list=['hp-toolbox'])
+
+opts, device_uri, printer_name, mode, ui_toolkit, loc = \
+    mod.parseStdOpts('o', ['output='])
 
-printer_name = None
-device_uri = None
-bus = device.DEFAULT_PROBE_BUS
-log_level = logger.DEFAULT_LOG_LEVEL
-mode = GUI_MODE
-mode_specified = False
 output_dir = os.getcwd()
-loc = None
-
-if os.getenv("HPLIP_DEBUG"):
-    log.set_level('debug')
 
 for o, a in opts:
-    if o in ('-h', '--help'):
-        usage()
-
-    elif o == '--help-rest':
-        usage('rest')
-
-    elif o == '--help-man':
-        usage('man')
-
-    elif o == '--help-desc':
-        print __doc__,
-        sys.exit(0)
-
-    elif o in ('-p', '--printer'):
-        printer_name = a
-
-    elif o in ('-d', '--device'):
-        device_uri = a
-
-    elif o in ('-b', '--bus'):
-        bus = a.lower().strip()
-        if not device.validateBusList(bus):
-            usage()
-
-    elif o in ('-l', '--logging'):
-        log_level = a.lower().strip()
-        if not log.set_level(log_level):
-            usage()
-
-    elif o == '-g':
-        log.set_level('debug')
-
-    elif o in ('-i', '--interactive'):
-        if mode_specified:
-            log.error("You may only specify a single mode as a parameter (-i, -n or -u).")
-            sys.exit(1)
-
-        mode = INTERACTIVE_MODE
-        mode_specified = True
-
-    elif o in ('-u', '--gui'):
-        if mode_specified:
-            log.error("You may only specify a single mode as a parameter (-i, -n or -u).")
-            sys.exit(1)
-
-        mode = GUI_MODE
-        mode_specified = True
-
-    elif o in ('-n', '--non-interactive'):
-        if mode_specified:
-            log.error("You may only specify a single mode as a parameter (-i, -n or -u).")
-            sys.exit(1)
-
-        mode = NON_INTERACTIVE_MODE
-        mode_specified = True
-
-    elif o in ('-o', '--output'):
+    if o in ('-o', '--output'):
         output_dir = a
-        
-    elif o in ('-q', '--lang'):
-        if a.strip() == '?':
-            utils.show_languages()
-            sys.exit(0)
-            
-        loc = utils.validate_language(a.lower())
-
-
-utils.log_title(__title__, __version__)
-
-# Security: Do *not* create files that other users can muck around with
-os.umask (0037)
 
 if mode == GUI_MODE:
     if not utils.canEnterGUIMode():
         mode = INTERACTIVE_MODE
 
+if mode == GUI_MODE:
+    if ui_toolkit == 'qt4':
+        log.error("%s does not support Qt4. Please use Qt3 or run in -i or -n modes.")
+        sys.exit(1)
+
 if mode in (INTERACTIVE_MODE, NON_INTERACTIVE_MODE):
-    if device_uri and printer_name:
-        log.error("You may not specify both a printer (-p) and a device (-d).")
-        usage()
+    try:
+        device_uri = mod.getDeviceUri(device_uri, printer_name,
+            filter={'pcard-type' : (operator.eq, 1)})
 
-
-    if printer_name:
-        printer_list = cups.getPrinters()
-        found = False
-        for p in printer_list:
-            if p.name == printer_name:
-                found = True
-
-        if not found:
-            log.error("Unknown printer name: %s" % printer_name)
+        try:
+            pc = photocard.PhotoCard( None, device_uri, printer_name )
+        except Error, e:
+            log.error("Unable to start photocard session: %s" % e.msg)
             sys.exit(1)
 
+        pc.set_callback(update_spinner)
 
-    if not device_uri and not printer_name:
         try:
-            device_uri = device.getInteractiveDeviceURI(bus, {'pcard-type' : (operator.gt, 0)})
-            if device_uri is None:
-                sys.exit(1)
+            pc.mount()
         except Error:
-            log.error("Error occured during interactive mode. Exiting.")
+            log.error("Unable to mount photo card on device. Check that device is powered on and photo card is correctly inserted.")
+            pc.umount()
+            # TODO:
+            #pc.device.sendEvent(EVENT_PCARD_UNABLE_TO_MOUNT, typ='error')
             sys.exit(1)
 
-    try:
-        pc = photocard.PhotoCard( None, device_uri, printer_name )
-    except Error, e:
-        log.error("Unable to start photocard session: %s" % e.msg)
-        sys.exit(1)
+        log.info(log.bold("\nPhotocard on device %s mounted" % pc.device.device_uri))
+        log.info(log.bold("DO NOT REMOVE PHOTO CARD UNTIL YOU EXIT THIS PROGRAM"))
 
-    pc.set_callback(update_spinner)
+        output_dir = os.path.realpath(os.path.normpath(os.path.expanduser(output_dir)))
 
-    if pc.device.device_uri is None and printer_name:
-        log.error("Printer '%s' not found." % printer_name)
-        sys.exit(1)
-
-    if pc.device.device_uri is None and device_uri:
-        log.error("Malformed/invalid device-uri: %s" % device_uri)
-        sys.exit(1)
-        
-    user_cfg.last_used.device_uri = pc.device.device_uri
-
-    pc.device.sendEvent(EVENT_START_PCARD_JOB)
-
-    try:
-        pc.mount()
-    except Error:
-        log.error("Unable to mount photo card on device. Check that device is powered on and photo card is correctly inserted.")
-        pc.umount()
-        pc.device.sendEvent(EVENT_PCARD_UNABLE_TO_MOUNT, typ='error')
-        sys.exit(1)
-
-    log.info(log.bold("\nPhotocard on device %s mounted" % pc.device.device_uri))
-    log.info(log.bold("DO NOT REMOVE PHOTO CARD UNTIL YOU EXIT THIS PROGRAM"))
-
-    output_dir = os.path.realpath(os.path.normpath(os.path.expanduser(output_dir)))
-
-    try:
-        os.chdir(output_dir)
-    except OSError:
-        print log.bold("ERROR: Output directory %s not found." % output_dir)
-        sys.exit(1)
-
-
-
-    if mode == INTERACTIVE_MODE: # INTERACTIVE_MODE
-
-        console = Console(pc)
         try:
+            os.chdir(output_dir)
+        except OSError:
+            print log.bold("ERROR: Output directory %s not found." % output_dir)
+            sys.exit(1)
+
+
+        if mode == INTERACTIVE_MODE: # INTERACTIVE_MODE
+            console = Console(pc)
             try:
-                console . cmdloop()
-            except KeyboardInterrupt:
-                log.error("Aborted.")
-            except Exception, e:
-                log.error("An error occured: %s" % e)
-        finally:
-            pc.umount()
+                try:
+                    console . cmdloop()
+                except KeyboardInterrupt:
+                    log.error("Aborted.")
+                except Exception, e:
+                    log.error("An error occured: %s" % e)
+            finally:
+                pc.umount()
 
-        pc.device.sendEvent(EVENT_END_PCARD_JOB)
+            # TODO:
+            #pc.device.sendEvent(EVENT_END_PCARD_JOB)
 
 
-    else: # NON_INTERACTIVE_MODE
-        print "Output directory is %s" % os.getcwd()
-        try:
+        else: # NON_INTERACTIVE_MODE
+            print "Output directory is %s" % os.getcwd()
             try:
                 unload_list = pc.get_unload_list()
                 print
@@ -823,55 +688,65 @@ if mode in (INTERACTIVE_MODE, NON_INTERACTIVE_MODE):
                     total, delta, was_cancelled = pc.unload(unload_list, status_callback, None, True)
                     print log.bold("\n%s unloaded in %d sec (%d KB/sec)" % (utils.format_bytes(total), delta, (total/1024)/delta))
 
-            except KeyboardInterrupt:
-                log.error("Aborted.")
-                pass
 
-        finally:
-            pc.umount()
+            finally:
+                pc.umount()
+
+    except KeyboardInterrupt:
+        log.error("User exit")
 
 
-else: # GUI_MODE
-
-    from qt import *
-    from ui import unloadform
+else: # GUI_MODE (qt3 only)
+    try:
+        from qt import *
+        from ui import unloadform
+    except ImportError:
+        log.error("Unable to load Qt3 support. Is it installed?")
+        sys.exit(1)
 
     app = QApplication(sys.argv)
     QObject.connect(app, SIGNAL("lastWindowClosed()"), app, SLOT("quit()"))
-    
+
     if loc is None:
-        loc = user_cfg.ui.get("loc", "system")
+        loc = user_conf.get('ui', 'loc', 'system')
         if loc.lower() == 'system':
             loc = str(QTextCodec.locale())
             log.debug("Using system locale: %s" % loc)
-    
+
     if loc.lower() != 'c':
+        e = 'utf8'
+        try:
+            l, x = loc.split('.')
+            loc = '.'.join([l, e])
+        except ValueError:
+            l = loc
+            loc = '.'.join([loc, e])
+
         log.debug("Trying to load .qm file for %s locale." % loc)
         trans = QTranslator(None)
-        qm_file = 'hplip_%s.qm' % loc
+
+        qm_file = 'hplip_%s.qm' % l
         log.debug("Name of .qm file: %s" % qm_file)
         loaded = trans.load(qm_file, prop.localization_dir)
-        
+
         if loaded:
             app.installTranslator(trans)
         else:
             loc = 'c'
-    
+
     if loc == 'c':
         log.debug("Using default 'C' locale")
     else:
         log.debug("Using locale: %s" % loc)
-        
         QLocale.setDefault(QLocale(loc))
+        prop.locale = loc
         try:
-            locale.setlocale(locale.LC_ALL, locale.normalize(loc+".utf8"))
-            prop.locale = loc
+            locale.setlocale(locale.LC_ALL, locale.normalize(loc))
         except locale.Error:
-            log.error("Invalid locale: %s" % (loc+".utf8"))        
-
+            pass
 
     try:
-        w = unloadform.UnloadForm(bus, device_uri, printer_name)
+        w = unloadform.UnloadForm(['cups'], device_uri, printer_name)
     except Error:
         log.error("Unable to connect to HPLIP I/O. Please (re)start HPLIP and try again.")
         sys.exit(1)
@@ -881,6 +756,5 @@ else: # GUI_MODE
 
     app.exec_loop()
 
+log.info("")
 log.info("Done.")
-sys.exit(0)
-
